import api from "./api";

interface LoginData {
  email: string;
  senha: string;
  permanecerLogado:boolean;
}

interface TokenResponse {
  token: string;
}

export async function login(data: LoginData): Promise<TokenResponse> {
  try {
    console.log("Iniciando requisição de login com os dados:", data);

    // Realiza a requisição para o endpoint de login
    const response = await api.post<TokenResponse>("/autenticacao/login", data);

    // Exibe a resposta recebida
    console.log("Login bem-sucedido. Resposta do backend:", response.data);

    // Retorna os dados da resposta (token)
    return response.data;
  } catch (error: any) {
    // Log do erro
    if (error.response) {
      console.error("Erro de resposta do backend:", {
        status: error.response.status,
        data: error.response.data,
      });
    } else if (error.request) {
      console.error("Erro na requisição ao backend. Sem resposta recebida:", error.request);
    } else {
      console.error("Erro ao configurar a requisição:", error.message);
    }

    // Lança um erro com uma mensagem amigável
    throw new Error(
      error.response?.data?.message || "Erro inesperado ao fazer login. Tente novamente mais tarde."
    );
  }
}

